import { buildUUID } from '../../../utils/uuid';
import { ApiAction, ApiActionPage } from '../../model/baseModel';
import {
  MaterialRetListItem,
  MaterialRetPageListGetResultModel,
  MaterialRetPageParams,
  MaterialRetDetailPageListGetResultModel,
  MaterialRetDetailPageParams,
  MaterialRetDetailSNPageListGetResultModel,
  MaterialRetDetailSNPageParams,
} from '../model/warehoueseModel';
import { genAction, Api, genActionPage } from '../system';
import { useUserStore } from '/@/store/modules/user';
import { defHttp } from '/@/utils/http/axios';
import { isNullOrEmpty } from '/@/utils/is';

/*
 * 获取生产退料分页列表
 */
export const getMaterialRetListByPage = async (params: MaterialRetPageParams) => {
  let order = 'UPDATE_TIME desc'
  if (params.order != undefined) {
    order = params.order == 'descend' ? (params.field + ' desc') : params.field
  }
  let sqlcmd = '1=1';
  if (params?.BILLCODE != undefined && params?.BILLCODE != '') {
    sqlcmd += " And BILLCODE like '%" + params?.BILLCODE + "%'";
  }
  if (params?.BILLDATE != undefined && params?.BILLDATE != '') {
    sqlcmd += " And BILLDATE > '" + params?.BILLDATE[0] + "'";
  }
  if (params?.BILLDATE != undefined && params?.BILLDATE != '') {
    sqlcmd += " And BILLDATE < '" + params?.BILLDATE[1] + "'";
  }
  if (!isNullOrEmpty(params?.STATUS)) {
    sqlcmd += " And STATUS = '" + params?.STATUS + "'";
  }
  var option ={
    UserId:useUserStore().getUserInfo.userId as string,
    ByOrg:true,
    OrgCode:useUserStore().getUserInfo.orgCode as string
  }
  const usParams = genAction('BIZ_ERP_PROD_RETURN', {
    QueryAble_T: '',
    where: sqlcmd,
    order: order,
    page: {
      pageAble_T: 'string',
      draw: 1,
      pageIndex: params.page,
      pageSize: params.pageSize,
    },
    option
  },option);
  //const rParams = genActionPage('V_BIZ_ERP_OTH_OUT_DTL', sqlcmd, params.page, params.pageSize,option);
  return getMaterialRetListByPageAsync(usParams);
  // const rParams = genActionPage('BIZ_ERP_PROD_RETURN', sqlcmd, params.page, params.pageSize,option);
  // return getMaterialRetListByPageAsync(rParams);
};
async function getMaterialRetListByPageAsync(params: any) {
  const data = await defHttp.post(
    { url: Api.QueryUrl, params },
    {
      isTransformResponse: false,
    },
  );
  const model = {
    items: data.Data.page.data,
    total: data.Data.page.totals,
  };
  return model;
}
/*
*生产退料明细
*/
export const getMaterialRetDetailListByPage = async (params: MaterialRetDetailPageParams) => {
  let order = ''
  if (params.order != undefined) {
    order = params.order == 'descend' ? (params.field + ' desc') : params.field
  }
  let sqlcmd = '1=1';
  if (params?.BILLCODE != undefined && params?.BILLCODE != '') {
    sqlcmd += " And BILLCODE like '%" + params?.BILLCODE + "%'";
  }
  if (params?.ITEM_CODE != undefined && params?.ITEM_CODE != '') {
    sqlcmd += " And ITEM_CODE like '%" + params?.ITEM_CODE + "%'";
  }
  if (!isNullOrEmpty(params?.LINESTATUS)) {
    sqlcmd += " And LINESTATUS = '" + params?.LINESTATUS + "'";
  }
  var option ={
    UserId:useUserStore().getUserInfo.userId as string,
    ByOrg:true,
    OrgCode:useUserStore().getUserInfo.orgCode as string
  }
  if (!isNullOrEmpty(params.page)) {
    const usParams = genAction('V_BIZ_ERP_PROD_RETURN_DTL', {
      QueryAble_T: '',
      where: sqlcmd,
      order: 'BILLLINE*1 '+order,
      page: {
        pageAble_T: 'string',
        draw: 1,
        pageIndex: params.page,
        pageSize: params.pageSize,
      },
      option
    },option);
    //const rParams = genActionPage('V_BIZ_ERP_OTH_OUT_DTL', sqlcmd, params.page, params.pageSize,option);
    return getMaterialRetDetailListByPageAsync(usParams);
  } else {
    const usParams = genAction('V_BIZ_ERP_PROD_RETURN_DTL', {
      QueryAble_T: '',
      where: sqlcmd,
      order: 'BILLLINE*1',
      option
    },option);
    //const rParams = genActionPage('V_BIZ_ERP_OTH_OUT_DTL', sqlcmd, params.page, params.pageSize,option);
    return getMaterialRetDetailListByPageAsync(usParams);
  }
};
async function getMaterialRetDetailListByPageAsync(params: any) {
  const data = await defHttp.post(
    { url: Api.QueryUrl, params },
    {
      isTransformResponse: false,
    },
  );
  let model = {}
  if (isNullOrEmpty(data.Data.page)) {
    model = {
      items: data.Data.Items,
    };
  } else {
    model = {
      items: data.Data.page.data,
      total: data.Data.page.totals,
    };
  }
  return model;
}
// async function getMaterialRetDetailListByPageAsync(params: ApiActionPage) {
//   const data = await defHttp.post<ApiActionPage>(
//     { url: Api.EntityPageList, params },
//     {
//       isTransformResponse: false,
//     },
//   );
//   const model: MaterialRetDetailPageListGetResultModel = {
//     items: data.Data.data,
//     total: data.Data.totals,
//   };
//   return model;
// }
//条码
export const getMaterialRetDetailSNListByPage = async (params: MaterialRetDetailSNPageParams) => {
  let order = ''
  if (params.order != undefined) {
    order = params.order == 'descend' ? (params.field + ' desc') : params.field
  }
  let sqlcmd = '1=1';
  if (params?.BILLCODE != undefined && params?.BILLCODE != '') {
    sqlcmd += " And BUSINESSCODE like '%" + params?.BILLCODE + "%'";
  }
  if (params?.ITEM_CODE != undefined && params?.ITEM_CODE != '') {
    sqlcmd += " And ITEM_CODE like '%" + params?.ITEM_CODE + "%'";
  }
  if (params?.SN != undefined && params?.SN != '') {
    sqlcmd += " And SN like '%" + params?.SN + "%'";
  }
  // if (params?.STATUS != undefined && params?.STATUS != '') {
  //   sqlcmd += " And STATUS = '" + params?.STATUS + "'";
  // }
  var option ={
    UserId:useUserStore().getUserInfo.userId as string,
    ByOrg:true,
    OrgCode:useUserStore().getUserInfo.orgCode as string
  }
  if (!isNullOrEmpty(params.page)) {
    const usParams = genAction('BIZ_ERP_PROD_RETURN_SN', {
      QueryAble_T: '',
      where: sqlcmd,
      order:order,
      page: {
        pageAble_T: 'string',
        draw: 1,
        pageIndex: params.page,
        pageSize: params.pageSize,
      },
      option
    },option);
    //const rParams = genActionPage('V_BIZ_ERP_OTH_OUT_DTL', sqlcmd, params.page, params.pageSize,option);
    return getMaterialRetDetailSNListByPageAsync(usParams);
  } else {
    const usParams = genAction('BIZ_ERP_PROD_RETURN_SN', {
      QueryAble_T: '',
      where: sqlcmd,
      option
    },option);
    //const rParams = genActionPage('V_BIZ_ERP_OTH_OUT_DTL', sqlcmd, params.page, params.pageSize,option);
    return getMaterialRetDetailSNListByPageAsync(usParams);
  }
};
async function getMaterialRetDetailSNListByPageAsync(params: any) {
  const data = await defHttp.post(
    { url: Api.QueryUrl, params },
    {
      isTransformResponse: false,
    },
  );
  let model = {}
  if (isNullOrEmpty(data.Data.page)) {
    model = {
      items: data.Data.Items,
    };
  } else {
    model = {
      items: data.Data.page.data,
      total: data.Data.page.totals,
    };
  }
  return model;
}

export const SaveMaterialRet = async (params: MaterialRetListItem, isUpdate: boolean) => {
  let data;
  if (isUpdate) {
    data = await defHttp.post(
      { url: Api.UpdateEntity, params: genAction('Minsun.WMS_PRDRETURN_H', params) },
      {
        errorMessageMode: 'none',
        isTransformResponse: false,
      },
    );
  } else {
    params.ID = buildUUID(); //生成GUID
    data = await defHttp.post(
      { url: Api.AddEntity, params: genAction('Minsun.WMS_PRDRETURN_H', params) },
      {
        errorMessageMode: 'none',
        isTransformResponse: false,
      },
    );
  }
  return data;
};

export const DeleteMaterialRet = async (params: Recordable) => {
  const usParams = genAction('FACTORY', [params]);
  return await defHttp.post(
    { url: Api.DeleteList, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
    },
  );
};
// 下拉列表
// STATUSs 单据状态
// BIZTYPEs 单据类型
export const optionsListApi = async (params: Recordable) => {
  const usParams = genAction('BIZ_ERP_PROD_RETURN+STATUSs', '');
  return await defHttp.post(
    { url: Api.urlQueryEnum, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      // apiUrl: globSetting.taskApiUrl
    },
  );
};
// export const optionTypeListApi = async (params: Recordable) => {
//   const usParams = genAction('BIZ_ERP_PROD_RETURN+BIZTYPEs', '');
//   return await defHttp.post(
//     { url: Api.urlQueryEnum, params: usParams },
//     {
//       errorMessageMode: 'none',
//       isTransformResponse: false,
//       // apiUrl: globSetting.taskApiUrl
//     },
//   );
// };
